=====
pynik
=====

This is purely a project trying out packaging of python
code to Pypi.

Trying out Styling guide
------------------------

This also outlines some of the ways of formatting text
with rst, which is unfamiliar.
